Package: VisiumIO
Title: Import Visium data from the 10X Space Ranger pipeline
Version: 1.7.7
Authors@R: c(
    person("Marcel", "Ramos", , "marcel.ramos@sph.cuny.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3242-0582")),
    person("Estella YiXing", "Dong", role = c("aut", "ctb")),
    person("Dario", "Righelli", role = c("aut", "ctb")),
    person("Helena", "Crowell", role = c("aut", "ctb")),
    person("NCI", role = "fnd",
           comment = c(GrantNo. = "U24CA289073"))
  )
Description: The package allows users to readily import spatial data obtained
    from either the 10X website or from the Space Ranger pipeline.
    Supported formats include tar.gz, h5, and mtx files. Multiple files
    can be imported at once with *List type of functions. The package
    represents data mainly as SpatialExperiment objects.
License: Artistic-2.0
Depends: R (>= 4.5.0), TENxIO
Imports: BiocBaseUtils, BiocGenerics, BiocIO (>= 1.15.1), jsonlite,
        methods, S4Vectors, SingleCellExperiment, SpatialExperiment,
        SummarizedExperiment
Suggests: arrow, BiocStyle, data.table, knitr, readr, rmarkdown, sf,
        tinytest
biocViews: Software, Infrastructure, DataImport, SingleCell, Spatial
VignetteBuilder: knitr
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
BugReports: https://github.com/waldronlab/VisiumIO/issues
URL: https://github.com/waldronlab/VisiumIO
Collate: 'TENxGeoJSON.R' 'TENxParquet-class.R' 'TENxSpatialCSV.R'
        'TENxSpatialList-class.R' 'TENxSpatialParquet.R'
        'TENxVisium-class.R' 'TENxVisiumList-class.R'
        'TENxVisiumHD-class.R' 'VisiumIO-package.R' 'utilities.R'
Date: 2025-12-24
git_url: https://git.bioconductor.org/packages/VisiumIO
git_branch: devel
git_last_commit: 989b6eb
git_last_commit_date: 2026-03-25
Repository: Bioconductor 3.23
Date/Publication: 2026-03-25
NeedsCompilation: no
Packaged: 2026-03-25 22:12:03 UTC; biocbuild
Author: Marcel Ramos [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3242-0582>),
  Estella YiXing Dong [aut, ctb],
  Dario Righelli [aut, ctb],
  Helena Crowell [aut, ctb],
  NCI [fnd] (GrantNo.: U24CA289073)
Maintainer: Marcel Ramos <marcel.ramos@sph.cuny.edu>
Built: R 4.6.0; ; 2026-03-26 04:09:40 UTC; unix
