# Generated by roxygen2: do not edit by hand

export(TENxGeoJSON)
export(TENxMappingParquet)
export(TENxParquet)
export(TENxSpatialCSV)
export(TENxSpatialList)
export(TENxSpatialParquet)
export(TENxVisium)
export(TENxVisiumHD)
export(TENxVisiumList)
export(compareBarcodes)
export(st_invert_y)
exportClasses(TENxGeoJSON)
exportClasses(TENxParquet)
exportClasses(TENxSpatialCSV)
exportClasses(TENxSpatialList)
exportClasses(TENxSpatialParquet)
exportClasses(TENxVisium)
exportClasses(TENxVisiumHD)
exportClasses(TENxVisiumList)
exportMethods(import)
import(TENxIO)
importClassesFrom(TENxIO,TENxFile)
importFrom(BiocBaseUtils,checkInstalled)
importFrom(BiocBaseUtils,isScalarCharacter)
importFrom(BiocBaseUtils,isScalarNumber)
importFrom(BiocGenerics,cbind)
importFrom(BiocGenerics,path)
importFrom(BiocIO,FileForFormat)
importFrom(BiocIO,decompress)
importFrom(BiocIO,import)
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,SimpleList)
importFrom(S4Vectors,metadata)
importFrom(SingleCellExperiment,altExps)
importFrom(SingleCellExperiment,mainExpName)
importFrom(SpatialExperiment,SpatialExperiment)
importFrom(SummarizedExperiment,"colData<-")
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(TENxIO,TENxFile)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,new)
